"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const table_data_1 = require("@src/table-data");
const table_expect_1 = require("@src/table-expect");
const utils_1 = require("./support/utils");
test('should expectTableRowCountToBeGreaterThan', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectTableRowCountToBeGreaterThan)(dataFrame, 3);
}));
test('should expectColumnValuesToMatchRegex', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnValuesToMatchRegex)(dataFrame, 'Age', '\\d{1,2}');
}));
test('should expectColumnValuesToBeInRange', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnValuesToBeInRange)(dataFrame, 'Age', 0, 45);
}));
test('should expectColumnValuesToBeNumbers', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnValuesToBeNumbers)(dataFrame, 'Age');
}));
test('should expectColumnToMatchWhenFilteredBy', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnToMatchWhenFilteredBy)(dataFrame, 'Age', '22', 'Person', 'Chris');
}));
test('should expectColumnToMatchGroupWhenFilteredBy', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    const group = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnToMatchGroupWhenFilteredBy)(dataFrame, 'Age', '22', group);
}));
test('should expectColumnToNotMatch', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnToNotMatch)(dataFrame, 'Age', '100');
}));
test('should expectTableRowCountToBe', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectTableRowCountToBe)(dataFrame, 4);
}));
test('should expectTableRowCountToBe', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectTableRowCountToBe)(dataFrame, 4);
}));
test('should expectColumnToBeValue', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnToBeValue)(dataFrame, 'Person', 'Chris');
}));
test('should expectColumnGroupToBeValue', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const group = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnGroupToBeValue)(dataFrame, group);
}));
test('should expectColumnGroupToBeValues', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_2_row.html');
    const groupA = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
        { filterColumn: 'Age', filterValue: '22' },
    ];
    const groupB = [
        { filterColumn: 'Person', filterValue: 'Dennis' },
        { filterColumn: 'Likes', filterValue: 'Web accessibility' },
        { filterColumn: 'Age', filterValue: '45' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectColumnGroupToBeValues)(dataFrame, [groupA, groupB]);
}));
test('should expectTableToNotMatch', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString1 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const htmlString2 = yield (0, utils_1.getHTMLFile)('table_1b_row.html');
    // Act
    const dataFrame1 = (0, table_data_1.toDataFrame)(htmlString1, utils_1.defaultHeaders);
    const dataFrame2 = (0, table_data_1.toDataFrame)(htmlString2, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectTableToNotMatch)(dataFrame1, dataFrame2);
}));
test('should expectTableToMatch', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString1 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const htmlString2 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    // Act
    const dataFrame1 = (0, table_data_1.toDataFrame)(htmlString1, utils_1.defaultHeaders);
    const dataFrame2 = (0, table_data_1.toDataFrame)(htmlString2, utils_1.defaultHeaders);
    // Act
    (0, table_expect_1.expectTableToMatch)(dataFrame1, dataFrame2);
}));
